#ifndef UAE_ENFORCER_H
#define UAE_ENFORCER_H

int enforcer_enable(int);
int enforcer_disable(void);

extern int enforcermode;

#endif // UAE_ENFORCER_H
